@@ -78,40 +78,6 @@
 #'       preferable to check model assumptions based on visual inspection
 #'       (see \code{\link[sjPlot]{plot_model}} with \code{type = "diag"}).
 #'
-#' @examples
-#' data(efc)
-#'
-#' fit <- lm(barthtot ~ c160age + c12hour + c161sex + c172code, data = efc)
-#' outliers(fit)
-#' heteroskedastic(fit)
-#' autocorrelation(fit)
-#' normality(fit)
-#' check_assumptions(fit)
-#'
-#' fit <- lm(barthtot ~ c160age + c12hour + c161sex + c172code + neg_c_7,
-#'           data = efc)
-#' outliers(fit)
-#' check_assumptions(fit, as.logical = TRUE)
-#'
-#' # apply function to multiple models in list-variable
-#' library(purrr)
-#' library(dplyr)
-#' tmp <- efc %>%
-#'   bootstrap(50) %>%
-#'   mutate(
-#'     models = map(strap, ~lm(neg_c_7 ~ e42dep + c12hour + c161sex, data = .x))
-#'   )
-#'
-#' # for list-variables, argument 'model.column' is the
-#' # quoted name of the list-variable with fitted models
-#' tmp %>% normality("models")
-#' tmp %>% heteroskedastic("models")
-#'
-#' # Durbin-Watson-Test from package 'car' takes a little bit longer due
-#' # to simulation of p-values...
-#' \dontrun{
-#' tmp %>% check_assumptions("models", as.logical = TRUE, reps = 100)}
-#'
 #' @importFrom stats formula
 #' @export
 check_assumptions <- function(x, model.column = NULL, as.logical = FALSE, ...) {
@@ -155,6 +121,8 @@ outliers <- function(x, iterations = 5) {
     stop("Package `car` needed for this function to work. Please install it.", call. = F)
   }
 
+  .Deprecated("performance::check_outliers()")
+
   # copy current model
   model <- x
   # maximum loops
@@ -283,6 +251,8 @@ heteroskedastic <- function(x, model.column = NULL) {
     stop("Package `car` needed for this function to work. Please install it.", call. = F)
   }
 
+  .Deprecated("performance::check_heteroscedasticity()")
+
   # check if we have list-variable, e.g. from nested data frames
   if (!is.null(model.column) && inherits(x[[model.column]], "list")) {
 
@@ -315,6 +285,8 @@ autocorrelation <- function(x, model.column = NULL, ...) {
     stop("Package `car` needed for this function to work. Please install it.", call. = F)
   }
 
+  .Deprecated("performance::check_autocorrelation()")
+
   # check if we have list-variable, e.g. from nested data frames
   if (!is.null(model.column) && inherits(x[[model.column]], "list")) {
 
@@ -343,6 +315,9 @@ autocorrelation <- function(x, model.column = NULL, ...) {
 #' @importFrom stats shapiro.test rstandard
 #' @export
 normality <- function(x, model.column = NULL) {
+
+  .Deprecated("performance::check_normality()")
+
   # check if we have list-variable, e.g. from nested data frames
   if (!is.null(model.column) && inherits(x[[model.column]], "list")) {
 
@@ -371,6 +346,9 @@ normality <- function(x, model.column = NULL) {
 #' @importFrom purrr map_lgl
 #' @export
 multicollin <- function(x, model.column = NULL) {
+
+  .Deprecated("performance::check_collinearity()")
+
   # check package availability
   if (!requireNamespace("car", quietly = TRUE)) {
     stop("Package `car` needed for this function to work. Please install it.", call. = F)
